@@ -1,9 +1,12 @@
-from time import sleep
 from geox.exceptions import APIKeyException, ParameterException, ServerErrorException
 from http import HTTPStatus
-from requests import request, Response
+from requests import request, Response, packages
 from requests.exceptions import ConnectionError, SSLError
+from time import sleep
+from urllib3.exceptions import InsecureRequestWarning
+import urllib3
 
+urllib3.disable_warnings(InsecureRequestWarning)
 
 def check_status_code(response: Response) -> None:
     '''checking all available status code from GeoX API'''
